@@ -29,14 +29,25 @@ class Scenario:
 
   def _init_scenario(self, j):
     self.srv.server_socket.settimeout(5)
-    j |= {"sready": True, "saddr": self.srv.host, "sport": self.srv.port, "sname": self.name}
-    self.cli._send(Scenario._encode_json(j))
+    ij = {"sready": True, "saddr": self.srv.host, "sport": self.srv.port, "sname": self.name}
+    self.cli._send(Scenario._encode_json(ij))
     res = Scenario._decode_json(self.srv._waits_for())
     self.srv.server_socket.settimeout(None)
-    if "stoken" not in res:
+    if "stoken" in res:
+      self.token = res["stoken"]
+      self.init = True
+      self._continue_scenario(j)
+    elif "squeued" in res:
+      while True:
+        try: res = Scenario._decode_json(self.srv._waits_for(buffer_size))
+        except UnicodeDecodeError: print('Unicode decode error.')
+        if "stoken" not in res: raise ScenarioNotStartedException
+        self.token = res["stoken"]
+        self.init = True
+        self._continue_scenario(j)
+        break
+    else:
       raise ScenarioNotStartedException
-    self.token = res["stoken"]
-    self.init = True
 
   def _continue_scenario(self, j):
     j |= {"stoken": self.token, "scontinue": True}
